# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ExternalOrganizationTrustorLink(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ExternalOrganizationTrustorLink - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'external_organization_id': 'str',
            'trustor_org_id': 'str',
            'date_created': 'datetime',
            'external_organization_uri': 'str'
        }

        self.attribute_map = {
            'external_organization_id': 'externalOrganizationId',
            'trustor_org_id': 'trustorOrgId',
            'date_created': 'dateCreated',
            'external_organization_uri': 'externalOrganizationUri'
        }

        self._external_organization_id = None
        self._trustor_org_id = None
        self._date_created = None
        self._external_organization_uri = None

    @property
    def external_organization_id(self):
        """
        Gets the external_organization_id of this ExternalOrganizationTrustorLink.
        The id of a PureCloud External Organization entity in the External Contacts system that will be used to represent the trustor org

        :return: The external_organization_id of this ExternalOrganizationTrustorLink.
        :rtype: str
        """
        return self._external_organization_id

    @external_organization_id.setter
    def external_organization_id(self, external_organization_id):
        """
        Sets the external_organization_id of this ExternalOrganizationTrustorLink.
        The id of a PureCloud External Organization entity in the External Contacts system that will be used to represent the trustor org

        :param external_organization_id: The external_organization_id of this ExternalOrganizationTrustorLink.
        :type: str
        """
        
        self._external_organization_id = external_organization_id

    @property
    def trustor_org_id(self):
        """
        Gets the trustor_org_id of this ExternalOrganizationTrustorLink.
        The id of a PureCloud organization that has granted trust to this PureCloud organization

        :return: The trustor_org_id of this ExternalOrganizationTrustorLink.
        :rtype: str
        """
        return self._trustor_org_id

    @trustor_org_id.setter
    def trustor_org_id(self, trustor_org_id):
        """
        Sets the trustor_org_id of this ExternalOrganizationTrustorLink.
        The id of a PureCloud organization that has granted trust to this PureCloud organization

        :param trustor_org_id: The trustor_org_id of this ExternalOrganizationTrustorLink.
        :type: str
        """
        
        self._trustor_org_id = trustor_org_id

    @property
    def date_created(self):
        """
        Gets the date_created of this ExternalOrganizationTrustorLink.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_created of this ExternalOrganizationTrustorLink.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this ExternalOrganizationTrustorLink.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_created: The date_created of this ExternalOrganizationTrustorLink.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def external_organization_uri(self):
        """
        Gets the external_organization_uri of this ExternalOrganizationTrustorLink.
        The URI for the External Organization that is linked to the trustor org

        :return: The external_organization_uri of this ExternalOrganizationTrustorLink.
        :rtype: str
        """
        return self._external_organization_uri

    @external_organization_uri.setter
    def external_organization_uri(self, external_organization_uri):
        """
        Sets the external_organization_uri of this ExternalOrganizationTrustorLink.
        The URI for the External Organization that is linked to the trustor org

        :param external_organization_uri: The external_organization_uri of this ExternalOrganizationTrustorLink.
        :type: str
        """
        
        self._external_organization_uri = external_organization_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

